@@ -9,19 +9,26 @@ from ..base_types import DjangoListObjectBase
 
 class GenericPaginationField(graphene.Field):
     """
-        Generic paginations field class with all generic function needed to paginate queryset
+    Generic paginations field class with all generic function needed to paginate queryset
     """
 
     def __init__(self, _type, paginator_instance, *args, **kwargs):
-        kwargs.setdefault('args', {})
+        kwargs.setdefault("args", {})
 
         self.paginator_instance = paginator_instance
 
         kwargs.update(self.paginator_instance.to_graphql_fields())
-        kwargs.update({'description': '{} list, paginated by {}'.format(_type._meta.model.__name__,
-                                                                        paginator_instance.__name__)})
+        kwargs.update(
+            {
+                "description": "{} list, paginated by {}".format(
+                    _type._meta.model.__name__, paginator_instance.__name__
+                )
+            }
+        )
 
-        super(GenericPaginationField, self).__init__(graphene.List(_type), *args, **kwargs)
+        super(GenericPaginationField, self).__init__(
+            graphene.List(_type), *args, **kwargs
+        )
 
     @property
     def model(self):
@@ -32,8 +39,10 @@ class GenericPaginationField(graphene.Field):
             return self.paginator_instance.paginate_queryset(root.results, **kwargs)
         return None
 
-    def get_resolver(self, parent_resolver):
-        return partial(self.list_resolver, self.type.of_type._meta.model._default_manager)
+    def wrap_resolve(self, parent_resolver):
+        return partial(
+            self.list_resolver, self.type.of_type._meta.model._default_manager
+        )
 
 
 def _positive_int(integer_string, strict=False, cutoff=None):
